2022-04-29 Version: 1.1.2
- SeachTraces support TagMap.

2021-03-30 Version: 1.1.1
- Generated python 2019-08-08 for xtrace.

2021-01-23 Version: 1.1.0
- Generated python 2019-08-08 for xtrace.

2020-12-28 Version: 1.0.0
- AMP Version Change.

